==> lxqt-config_1.2.0.orig.tar.xz: lxqt-config-1.2.0/lxqt-config-input/translations/lxqt-config-input_uk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk">
<context>
    <name>KeyboardConfig</name>
    <message>
        <location filename="../keyboardconfig.ui" line="14"/>
        <source>Form</source>
        <translation>Форма</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="20"/>
        <source>Cursor flash time:</source>
        <translation>Час оновлення курсору:</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="27"/>
        <source>&lt;b&gt;Keyboard&lt;/b&gt;</source>
        <translation>&lt;b&gt;Клавіатура&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="34"/>
        <source>Beep when there is an error of keyboard input</source>
        <translation>Пікати коли є помилка вводу клавіатури</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="41"/>
        <source> ms</source>
        <translation> мс</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="51"/>
        <source>Character Repeat</source>
        <translation>Повторення символу</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="79"/>
        <location filename="../keyboardconfig.ui" line="143"/>
        <source>Long</source>
        <translation>Довго</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="108"/>
        <source>Repeat delay:</source>
        <translation>Затримка повторення:</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="115"/>
        <location filename="../keyboardconfig.ui" line="136"/>
        <source>Short</source>
        <translation>Коротко</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="122"/>
        <source>Repeat interval:</source>
        <translation>Інтервал повторення:</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="129"/>
        <source>Type in the following box to test your keyboard settings</source>
        <translation>Впишіть в наступному полі для тестування налаштувань клавіатури</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="150"/>
        <location filename="../keyboardconfig.ui" line="157"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="167"/>
        <source>Turn on NumLock after login</source>
        <translation>Вмикати NumLock після входу</translation>
    </message>
</context>
<context>
    <name>KeyboardLayoutConfig</name>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="20"/>
        <source>&lt;b&gt;Keyboard Layout&lt;/b&gt;</source>
        <translation>&lt;b&gt;Розкладка клавіатури&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="48"/>
        <source>Layout</source>
        <translation>Розкладка</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="53"/>
        <source>Variant</source>
        <translation>Варіант</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="63"/>
        <source>&amp;Add</source>
        <translation>&amp;Додати</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="70"/>
        <source>&amp;Remove</source>
        <translation>&amp;Вилучити</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="77"/>
        <source>Up</source>
        <translation>Вгору</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="84"/>
        <source>Down</source>
        <translation>Вниз</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="108"/>
        <source>Keyboard model:</source>
        <translation>Модель клавіатури:</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="122"/>
        <source>Keys to change layout:</source>
        <translation>Кнопки для зміни розкладки:</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="133"/>
        <source>None</source>
        <translation>Нічого</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="141"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Note&lt;/span&gt;: If you are using an &lt;span style=&quot; font-weight:600;&quot;&gt;input method&lt;/span&gt;, such as IBus, uim, fcitx, or gcin, the settings here &lt;span style=&quot; font-weight:600;&quot;&gt;might not work&lt;/span&gt; because they are overridden by the input methods.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Примітка&lt;/span&gt;: якщо ви користуєтеся такими &lt;span style=&quot; font-weight:600;&quot;&gt;методами введення&lt;/span&gt;, як IBus, uim, fcitx, або gcin, тоді налаштування тут &lt;span style=&quot; font-weight:600;&quot;&gt;можуть не спрацювати&lt;/span&gt;, тому що вони будуть перезаписані власними налаштуваннями методів введення.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
</context>
<context>
    <name>MouseConfig</name>
    <message>
        <location filename="../mouseconfig.ui" line="14"/>
        <source>Form</source>
        <translation>Форма</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="23"/>
        <source>&lt;b&gt;Mouse&lt;/b&gt;</source>
        <translation>&lt;b&gt;Миша&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="30"/>
        <source>Double click interval:</source>
        <translation>Інтервал подвійного клацання:</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="37"/>
        <source> ms</source>
        <translation> мс</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="47"/>
        <source>Wheel scroll lines:</source>
        <translation>Лінії прокрутки коліщатка:</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="64"/>
        <source>Left handed (Swap left and right mouse buttons)</source>
        <translation>Шульга (зміна місцями лівої і правої кнопок миші)</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="57"/>
        <source>Single click to activate items</source>
        <translation>Одинарне клацання для активування</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../lxqt-config-input.cpp" line="70"/>
        <source>Keyboard and Mouse Settings</source>
        <translation>Налаштування клавіатури і миші</translation>
    </message>
    <message>
        <location filename="../lxqt-config-input.cpp" line="79"/>
        <source>Mouse</source>
        <translation>Миша</translation>
    </message>
    <message>
        <location filename="../lxqt-config-input.cpp" line="88"/>
        <source>Cursor</source>
        <translation>Курсор</translation>
    </message>
    <message>
        <location filename="../lxqt-config-input.cpp" line="95"/>
        <source>Keyboard</source>
        <translation>Клавіатура</translation>
    </message>
    <message>
        <location filename="../lxqt-config-input.cpp" line="103"/>
        <source>Keyboard Layout</source>
        <translation>Розкладка клавіатури</translation>
    </message>
    <message>
        <location filename="../lxqt-config-input.cpp" line="112"/>
        <source>Mouse and Touchpad</source>
        <translation>Миша та сенсорна панель</translation>
    </message>
</context>
<context>
    <name>SelectKeyboardLayoutDialog</name>
    <message>
        <location filename="../selectkeyboardlayoutdialog.ui" line="14"/>
        <source>Select a keyboard layout</source>
        <translation>Вибір розкладки клавіатури</translation>
    </message>
    <message>
        <location filename="../selectkeyboardlayoutdialog.ui" line="20"/>
        <source>Keyboard layout</source>
        <translation>Розкладка клавіатури</translation>
    </message>
    <message>
        <location filename="../selectkeyboardlayoutdialog.ui" line="27"/>
        <source>Variant</source>
        <translation>Варіант</translation>
    </message>
</context>
<context>
    <name>TouchpadConfig</name>
    <message>
        <location filename="../touchpadconfig.ui" line="14"/>
        <source>TouchpadConfig </source>
        <translation>Налаштування сенсорної панелі </translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="20"/>
        <source>Device:</source>
        <translation>Пристрій:</translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="30"/>
        <source>Acceleration speed:</source>
        <translation>Швидкість прискорення:</translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="37"/>
        <source>Tap to click</source>
        <translation>Натиск для клацання</translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="44"/>
        <source>Natural Scrolling</source>
        <translation>Природне гортання</translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="51"/>
        <source>Tap and drag</source>
        <translation>Торкнутися для перетягування</translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="79"/>
        <source>Scrolling:</source>
        <translation>Прокручування:</translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="102"/>
        <source>&amp;Disabled</source>
        <translation>&amp;Вимкнено</translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="109"/>
        <source>&amp;Two-Finger</source>
        <translation>&amp;Двома пальцями</translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="116"/>
        <source>Ed&amp;ge</source>
        <translation>За &amp;край</translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="123"/>
        <source>B&amp;utton</source>
        <translation>К&amp;нопкою</translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="145"/>
        <source>DeviceInfoLabel</source>
        <translation>DeviceInfoLabel</translation>
    </message>
    <message>
        <location filename="../touchpadconfig.cpp" line="85"/>
        <source>LXQt only supports &quot;libinput&quot; as xinput driver.
(current value: %1)

If this is intended, please configure xinput manually.
Otherwise you can get rid of this message by changing xinput driver to &quot;libinput&quot;.
</source>
        <translation>LXQt підтримує лише &quot;libinput&quot; як драйвер xinput.
(поточне значення: %1)

Якщо це передбачено, налаштуйте xinput власноруч.
В іншому випадку ви можете позбутися цього повідомлення, змінивши драйвер xinput на &quot;libinput&quot;.
</translation>
    </message>
</context>
</TS>

==> lxqt-config_2.1.1.orig.tar.xz: lxqt-config-2.1.1/lxqt-config-input/translations/lxqt-config-input_uk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk">
<context>
    <name>KeyboardConfig</name>
    <message>
        <location filename="../keyboardconfig.ui" line="14"/>
        <source>Form</source>
        <translation>Форма</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="143"/>
        <source>Cursor flash time:</source>
        <translation>Час оновлення курсору:</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="20"/>
        <source>&lt;b&gt;Keyboard&lt;/b&gt;</source>
        <translation>&lt;b&gt;Клавіатура&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="160"/>
        <source>Beep when there is an error of keyboard input</source>
        <translation>Пікати коли є помилка вводу клавіатури</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="150"/>
        <source> ms</source>
        <translation> мс</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="27"/>
        <source>Character Repeat</source>
        <translation>Повторення символу</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="69"/>
        <location filename="../keyboardconfig.ui" line="116"/>
        <source>Long</source>
        <translation>Довго</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="33"/>
        <source>Repeat delay:</source>
        <translation>Затримка повторення:</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="40"/>
        <location filename="../keyboardconfig.ui" line="90"/>
        <source>Short</source>
        <translation>Коротко</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="83"/>
        <source>Repeat interval:</source>
        <translation>Інтервал повторення:</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="130"/>
        <source>Type in the following box to test your keyboard settings</source>
        <translation>Впишіть в наступному полі для тестування налаштувань клавіатури</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="76"/>
        <location filename="../keyboardconfig.ui" line="123"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="167"/>
        <source>Turn on NumLock after login</source>
        <translation>Вмикати NumLock після входу</translation>
    </message>
</context>
<context>
    <name>KeyboardLayoutConfig</name>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="20"/>
        <source>&lt;b&gt;Keyboard Layout&lt;/b&gt;</source>
        <translation>&lt;b&gt;Розкладка клавіатури&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="48"/>
        <source>Layout</source>
        <translation>Розкладка</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="53"/>
        <source>Variant</source>
        <translation>Варіант</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="63"/>
        <source>&amp;Add</source>
        <translation>&amp;Додати</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="70"/>
        <source>&amp;Remove</source>
        <translation>&amp;Вилучити</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="77"/>
        <source>Up</source>
        <translation>Вгору</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="84"/>
        <source>Down</source>
        <translation>Вниз</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="108"/>
        <source>Keyboard model:</source>
        <translation>Модель клавіатури:</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="122"/>
        <source>Keys to change layout:</source>
        <translation>Кнопки для зміни розкладки:</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="133"/>
        <source>None</source>
        <translation>Нічого</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="141"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Note&lt;/span&gt;: If you are using an &lt;span style=&quot; font-weight:600;&quot;&gt;input method&lt;/span&gt;, such as IBus, uim, fcitx, or gcin, the settings here &lt;span style=&quot; font-weight:600;&quot;&gt;might not work&lt;/span&gt; because they are overridden by the input methods.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Примітка&lt;/span&gt;: якщо ви користуєтеся такими &lt;span style=&quot; font-weight:600;&quot;&gt;методами введення&lt;/span&gt;, як IBus, uim, fcitx, або gcin, тоді налаштування тут &lt;span style=&quot; font-weight:600;&quot;&gt;можуть не спрацювати&lt;/span&gt;, тому що вони будуть перезаписані власними налаштуваннями методів введення.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
</context>
<context>
    <name>MouseConfig</name>
    <message>
        <location filename="../mouseconfig.ui" line="14"/>
        <source>Form</source>
        <translation>Форма</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="23"/>
        <source>&lt;b&gt;Mouse&lt;/b&gt;</source>
        <translation>&lt;b&gt;Миша&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="30"/>
        <source>Double click interval:</source>
        <translation>Інтервал подвійного клацання:</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="37"/>
        <source> ms</source>
        <translation> мс</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="47"/>
        <source>Wheel scroll lines:</source>
        <translation>Лінії прокрутки коліщатка:</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="64"/>
        <source>Left handed (Swap left and right mouse buttons)</source>
        <translation>Шульга (зміна місцями лівої і правої кнопок миші)</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="57"/>
        <source>Single click to activate items</source>
        <translation>Одинарне клацання для активування</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../lxqt-config-input.cpp" line="77"/>
        <source>Platform Unsupported</source>
        <translation>Непідтримувана платформа</translation>
    </message>
    <message>
        <location filename="../lxqt-config-input.cpp" line="38"/>
        <source>LXQt input settings are currently unsupported under Wayland.

Mouse, touchpad and keyboard can be configured in the settings of the compositor.</source>
        <translation>Налаштування вводу LXQt наразі не підтримуються у Wayland.

Мишу, тачпад і клавіатуру можна налаштувати у налаштуваннях композитора.</translation>
    </message>
    <message>
        <location filename="../lxqt-config-input.cpp" line="81"/>
        <source>Keyboard and Mouse Settings</source>
        <translation>Налаштування клавіатури і миші</translation>
    </message>
    <message>
        <location filename="../lxqt-config-input.cpp" line="90"/>
        <source>Mouse</source>
        <translation>Миша</translation>
    </message>
    <message>
        <location filename="../lxqt-config-input.cpp" line="99"/>
        <source>Cursor</source>
        <translation>Курсор</translation>
    </message>
    <message>
        <location filename="../lxqt-config-input.cpp" line="106"/>
        <source>Keyboard</source>
        <translation>Клавіатура</translation>
    </message>
    <message>
        <location filename="../lxqt-config-input.cpp" line="114"/>
        <source>Keyboard Layout</source>
        <translation>Розкладка клавіатури</translation>
    </message>
    <message>
        <location filename="../lxqt-config-input.cpp" line="123"/>
        <source>Mouse and Touchpad</source>
        <translation>Миша та сенсорна панель</translation>
    </message>
</context>
<context>
    <name>SelectKeyboardLayoutDialog</name>
    <message>
        <location filename="../selectkeyboardlayoutdialog.ui" line="14"/>
        <source>Select a keyboard layout</source>
        <translation>Вибір розкладки клавіатури</translation>
    </message>
    <message>
        <location filename="../selectkeyboardlayoutdialog.ui" line="20"/>
        <source>Keyboard layout</source>
        <translation>Розкладка клавіатури</translation>
    </message>
    <message>
        <location filename="../selectkeyboardlayoutdialog.ui" line="27"/>
        <source>Variant</source>
        <translation>Варіант</translation>
    </message>
</context>
<context>
    <name>TouchpadConfig</name>
    <message>
        <location filename="../touchpadconfig.ui" line="14"/>
        <source>TouchpadConfig </source>
        <translation>Налаштування сенсорної панелі </translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="20"/>
        <source>Device:</source>
        <translation>Пристрій:</translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="37"/>
        <source>Acceleration speed:</source>
        <translation>Швидкість прискорення:</translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="60"/>
        <source>Tap to click</source>
        <translation>Натиск для клацання</translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="67"/>
        <source>Natural Scrolling</source>
        <translation>Природне гортання</translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="74"/>
        <source>Tap and drag</source>
        <translation>Торкнутися для перетягування</translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="86"/>
        <source>Scrolling:</source>
        <translation>Прокручування:</translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="109"/>
        <source>&amp;Disabled</source>
        <translation>&amp;Вимкнено</translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="116"/>
        <source>&amp;Two-Finger</source>
        <translation>&amp;Двома пальцями</translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="123"/>
        <source>Ed&amp;ge</source>
        <translation>За &amp;край</translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="130"/>
        <source>B&amp;utton</source>
        <translation>К&amp;нопкою</translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="30"/>
        <source>DeviceInfoLabel</source>
        <translation>DeviceInfoLabel</translation>
    </message>
    <message>
        <location filename="../touchpadconfig.cpp" line="85"/>
        <source>LXQt only supports &quot;libinput&quot; as xinput driver.
(current value: %1)

If this is intended, please configure xinput manually.
Otherwise you can get rid of this message by changing xinput driver to &quot;libinput&quot;.
</source>
        <translation>LXQt підтримує лише &quot;libinput&quot; як драйвер xinput.
(поточне значення: %1)

Якщо це передбачено, налаштуйте xinput власноруч.
В іншому випадку ви можете позбутися цього повідомлення, змінивши драйвер xinput на &quot;libinput&quot;.
</translation>
    </message>
</context>
</TS>
